*             STANDARD RAP CODE FOR MDS 2.0
*                                      Last change date-------01/13/96

     ***************************************************************
     *Copyright, 1996, CHSRA The University of Wisconsin--Madison. *
     *Supported in part under Consultation Contract No.            *
     *500-94-0075 from the Health Care Financing Administration    *
     *entitled Consultation in Analysis of Long Term Care Survey   *
     *Pilot Tests and Use of Quality Indicators in Development of  *
     *a National Resident Assessment Database.                     *
     ***************************************************************


*This code was written and tested by Austin Data Managet Associates.


*                         DOCUMENTATION                        

***************************************************************************
*The following code implements the logic for the MDS 2.0 RAPs as Clipper 5
*   functions.  The characteristics of this code are as follows
*   1. An asterisk (*) at the beginning of a line represents a nonexecutable
*      comment.
*   2. Each RAP is encapsulated as a function.  The comment after the
*      initial function statement identifies the RAP, i.e. "RAP01 - Delirium".  
*      RAP numbering corresponds to the MDS RAP Summary Sheet.
*   3. The number of commands used in the code has been severely limited to 
*      ease conversion to other languages.  The only commands present are 
*      "FUNCTION", IF/ELSE/ENDIF (with nesting), and RETURN. 
*   4. The code assumes that the functions are called from a driver
*      program, and the driver program deals with the returned values.
*   5. Note that all MDS items are assumed to be character variables.
*      The naming convention for MDS items is to add a "c_" prefix to
*      the MDS item label (e.g., K3a) from the "Long Term Care Assessment
*      Instrument User's Manual: Version 2.0", yielding names such as c_K3a.  
*      The "c_" prefix indicates that the variable has character type values.
*      In this code, character type values are enclosed in single quotes.

*The status of each RAP can be triggered, not triggered, or unknown.
*   1. If triggered, the function returns a '1' for TRIGGERED.
*   2. If not triggered and there ARE NO missing or out-of-range
*      values which could be replaced with valid nonmissing values 
*      and cause the RAP to be triggered, the function returns a '0'
*      for NOT TRIGGERED.
*   3. If not triggered but there ARE missing or out-of-range values 
*      which could be replaced by valid nonmissing values and cause 
*      the RAP to be triggered, the function returns a '-' for
*      UNKNOWN TRIGGER STATUS.

*Sixteen of the 18 RAPs (excluding #10 and #17) have quite simple 
*logical structures.  Any one of the items involved in such a simple RAP
*will cause the RAP to be triggered, independent of the values for the
*other items.  The function for a simple RAP involves the following steps:
*   1. The function first scans the MDS items for the RAP to determine 
*      if any of the triggering conditions are present.  If any are 
*      present,the RAP is TRIGGERED (a '1' is returned).
*   2. If the RAP is not triggered, the function checks all MDS values 
*      considered in the trigger and to see if they are all valid
*      (within range) and nonmissing (not '-') values.  If all are valid
*      and nonmissing, the RAP is NOT TRIGGERED (a '0' is  returned).
*   3. If the RAP is not triggered and missing or invalid values are present
*      for any item, then RAP status is UNKNOWN due to missing or 
*      invalid data (a '-' is returned).

*The two more complex RAPs (#10 and #17) involve simultaneous consideration 
*of values for two or more different items as a triggering condition.  The 
*functions for these two RAPs are a bit more complicated.  Characteristics 
*of these functions are as follows:
*   1. Determination of TRIGGERED status is still straight-forward, and this 
*      is the first step.
*   2. If the RAP is not triggered and there is no missing or invalid data,
*      then the logic is again straight-forward and the resulting RAP 
*      status is NOT TRIGGERED.
*   3. If the RAP is not triggered but missing or invalid data occur, then
*      the greater complexity arises.  The resulting status may be 
*      NOT TRIGGERED or UNKNOWN based on a more-detailed analysis of the
*      pattern of values.

 
*                        BEGINNING OF CODE

*----------------------------------------------------------------------
Function RAP01
*Process RAP01--Delirium
   
*Scan values for RAP status
IF (c_B5a = '2' .OR.;
    c_B5b = '2' .OR.;
    c_B5c = '2' .OR.;
    c_B5d = '2' .OR.;
    c_B5e = '2' .OR.;
    c_B5f = '2' .OR.;
    c_B6  = '2' .OR.;
    c_E3  = '2' .OR.;
    c_E5  = '2')
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF (((c_B5a >= '0' .AND. c_B5a <= '2') .OR. c_B5a = ' ') .AND.;
       ((c_B5b >= '0' .AND. c_B5b <= '2') .OR. c_B5b = ' ') .AND.;
       ((c_B5c >= '0' .AND. c_B5c <= '2') .OR. c_B5c = ' ') .AND.;
       ((c_B5d >= '0' .AND. c_B5d <= '2') .OR. c_B5d = ' ') .AND.;
       ((c_B5e >= '0' .AND. c_B5e <= '2') .OR. c_B5e = ' ') .AND.;
       ((c_B5f >= '0' .AND. c_B5f <= '2') .OR. c_B5f = ' ') .AND.;
       ((c_B6  >= '0' .AND. c_B6  <= '2') .OR. c_B6  = ' ') .AND.;
       ((c_E3  >= '0' .AND. c_E3  <= '2') .OR. c_E3  = ' ') .AND.;
       ((c_E5  >= '0' .AND. c_E5  <= '2') .OR. c_E5  = ' '))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN  '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP01
 
*----------------------------------------------------------------------
Function RAP02
*Process RAP02--Cognitive Loss

*Scan values for RAP status
IF ( c_B2a =  '1'                    .OR.;
     c_B2b =  '1'                    .OR.; 
    (c_B4  >= '1' .AND. c_B4 <= '3') .OR.;
    (c_C6  >= '1' .AND. c_C6 <= '3'))
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF (( c_B2a =  '0' .OR.  c_B2a = '1'   .OR. c_B2a = ' ') .AND.;
       ( c_B2b =  '0' .OR.  c_B2b = '1'   .OR. c_B2b = ' ') .AND.; 
       ((c_B4  >= '0' .AND. c_B4  <= '3') .OR. c_B4  = ' ') .AND.;
       ((c_C6  >= '0' .AND. c_C6  <= '3') .OR. c_C6  = ' '))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP02

*----------------------------------------------------------------------
Function RAP03
*Process RAP03--Visual Function

*Scan values for RAP status
IF ( c_D2a  =  '1'                  .OR.;
     c_I1jj =  '1'                  .OR.; 
     c_I1ll =  '1'                  .OR.;
    (c_D1   >= '1' .AND. c_D1 <= '3'))
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF (( c_D2a  =  '0' .OR.  c_D2a   = '1'   .OR. c_D2a  = ' ') .AND.;
       ( c_I1jj =  '0' .OR.  c_I1jj  = '1'                    ) .AND.; 
       ( c_I1ll =  '0' .OR.  c_I1ll  = '1'                    ) .AND.;
       ((c_D1   >= '0' .AND. c_D1   <= '4')  .OR. c_D1   = ' '))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP03

*----------------------------------------------------------------------
Function RAP04
*Process RAP04--Communication

*Scan values for RAP status
IF ((c_C1 >= '1' .AND. c_C1 <= '3') .OR.;
    (c_C4 >= '1' .AND. c_C4 <= '3') .OR.; 
    (c_C6 >= '1' .AND. c_C6 <= '3'))
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF (((c_C1 >= '0' .AND. c_C1 <= '3') .OR. c_C1 = ' ') .AND.;
       ((c_C4 >= '0' .AND. c_C4 <= '3') .OR. c_C4 = ' ') .AND.; 
       ((c_C6 >= '0' .AND. c_C6 <= '3') .OR. c_C6 = ' '))
          *RAP is not triggered--return code of '0'
          RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP04

*----------------------------------------------------------------------
Function RAP05
*Process RAP05--ADL Function/Rehabilitation Potential

*Scan values for RAP status
IF ((c_G1aA >= '1' .AND. c_G1aA <= '4') .OR.;
    (c_G1bA >= '1' .AND. c_G1bA <= '4') .OR.;
    (c_G1cA >= '1' .AND. c_G1cA <= '4') .OR.;
    (c_G1dA >= '1' .AND. c_G1dA <= '4') .OR.;
    (c_G1eA >= '1' .AND. c_G1eA <= '4') .OR.;
    (c_G1fA >= '1' .AND. c_G1fA <= '4') .OR.;
    (c_G1gA >= '1' .AND. c_G1gA <= '4') .OR.;
    (c_G1hA >= '1' .AND. c_G1hA <= '4') .OR.;
    (c_G1iA >= '1' .AND. c_G1iA <= '4') .OR.;
    (c_G1jA >= '1' .AND. c_G1jA <= '4') .OR.;
    (c_G2A  >= '1' .AND. c_G2A  <= '4') .OR.;
     c_G8a  =  '1'                      .OR.;
     c_G8b  =  '1'                      .OR.;
     c_B4   = '3')
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF (((c_G1aA >= '0' .AND. c_G1aA <= '4') .OR. c_G1aA = '8') .AND.;                     
       ((c_G1bA >= '0' .AND. c_G1bA <= '4') .OR. c_G1bA = '8') .AND.;
       ((c_G1cA >= '0' .AND. c_G1cA <= '4') .OR. c_G1cA = '8') .AND.;
       ((c_G1dA >= '0' .AND. c_G1dA <= '4') .OR. c_G1dA = '8') .AND.;
       ((c_G1eA >= '0' .AND. c_G1eA <= '4') .OR. c_G1eA = '8') .AND.;
       ((c_G1fA >= '0' .AND. c_G1fA <= '4') .OR. c_G1fA = '8') .AND.;
       ((c_G1gA >= '0' .AND. c_G1gA <= '4') .OR. c_G1gA = '8') .AND.;
       ((c_G1hA >= '0' .AND. c_G1hA <= '4') .OR. c_G1hA = '8') .AND.;
       ((c_G1iA >= '0' .AND. c_G1iA <= '4') .OR. c_G1iA = '8') .AND.;
       ((c_G1jA >= '0' .AND. c_G1jA <= '4') .OR. c_G1jA = '8') .AND.;
       ((c_G2A  >= '0' .AND. c_G2A  <= '4') .OR. c_G2A  = '8') .AND.;
       ( c_G8a  =  '0' .OR.  c_G8a  =  '1'                   ) .AND.;
       ( c_G8b  =  '0' .OR.  c_G8b  =  '1'                   ) .AND.;
       ((c_B4   >= '0' .AND. c_B4   <= '3') .OR. c_B4   = ' '))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP05

*----------------------------------------------------------------------
Function RAP06
*Process RAP06--Urinary Continence and Indwelling Catheter

*Scan values for RAP status
IF ((c_H1b >= '2' .AND. c_H1b <= '4') .OR.;
     c_H3c =  '1' .OR.;
     c_H3d =  '1' .OR.;
     c_H3e =  '1' .OR.;
     c_H3g =  '1')
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF ((c_H1b >= '0' .AND. c_H1b <= '4') .AND.;
       (c_H3c =  '0' .OR.  c_H3c =  '1') .AND.;
       (c_H3d =  '0' .OR.  c_H3d =  '1') .AND.;
       (c_H3e =  '0' .OR.  c_H3e =  '1') .AND.;
       (c_H3g =  '0' .OR.  c_H3g =  '1'))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP06

*----------------------------------------------------------------------
Function RAP07
*Process RAP07--Psychosoial Well-Being

*Scan values for RAP status
IF ((c_E1o >= '1' .AND. c_E1o <= '2') .OR.;
     c_F2a =  '1'                     .OR.;
     c_F2b =  '1'                     .OR.;
     c_F2c =  '1'                     .OR.;
     c_F2d =  '1'                     .OR.;
     c_F3b =  '1'                     .OR.;
     c_F3c =  '1'                     .OR.;
     c_F1d =  '1'                     .OR.;
     c_F3a =  '1')
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF (((c_E1o >= '0' .AND. c_E1o <= '2') .OR. c_E1o = ' ')  .AND.;
       ( c_F2a =  '0' .OR.  c_F2a =  '1'  .OR. c_F2a = ' ')  .AND.;
       ( c_F2b =  '0' .OR.  c_F2b =  '1'  .OR. c_F2b = ' ')  .AND.;
       ( c_F2c =  '0' .OR.  c_F2c =  '1'  .OR. c_F2c = ' ')  .AND.;
       ( c_F2d =  '0' .OR.  c_F2d =  '1'  .OR. c_F2d = ' ')  .AND.;
       ( c_F3b =  '0' .OR.  c_F3b =  '1'  .OR. c_F3b = ' ')  .AND.;
       ( c_F3c =  '0' .OR.  c_F3c =  '1'  .OR. c_F3c = ' ')  .AND.;
       ( c_F1d =  '0' .OR.  c_F1d =  '1'  .OR. c_F1d = ' ')  .AND.;
       ( c_F3a =  '0' .OR.  c_F3a =  '1'  .OR. c_F3a = ' '))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP07

*----------------------------------------------------------------------
Function RAP08
*Process RAP08--Mood State

*Scan values for RAP status
IF ((c_E1a >= '1' .AND. c_E1a <= '2') .OR.;
    (c_E1b >= '1' .AND. c_E1b <= '2') .OR.;
    (c_E1c >= '1' .AND. c_E1c <= '2') .OR.;
    (c_E1d >= '1' .AND. c_E1d <= '2') .OR.;
    (c_E1e >= '1' .AND. c_E1e <= '2') .OR.;
    (c_E1f >= '1' .AND. c_E1f <= '2') .OR.;
    (c_E1g >= '1' .AND. c_E1g <= '2') .OR.;
    (c_E1h >= '1' .AND. c_E1h <= '2') .OR.;
    (c_E1i >= '1' .AND. c_E1i <= '2') .OR.;
    (c_E1j >= '1' .AND. c_E1j <= '2') .OR.;
    (c_E1k >= '1' .AND. c_E1k <= '2') .OR.;
    (c_E1l >= '1' .AND. c_E1l <= '2') .OR.;
    (c_E1m >= '1' .AND. c_E1m <= '2') .OR.;
    (c_E1n >= '1' .AND. c_E1n <= '2') .OR.;
    (c_E1o >= '1' .AND. c_E1o <= '2') .OR.;
    (c_E1p >= '1' .AND. c_E1p <= '2') .OR.;
    (c_E2  >= '1' .AND. c_E2  <= '2'))      
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF (((c_E1a >= '0' .AND. c_E1a <= '2') .OR. c_E1a = ' ') .AND.;
       ((c_E1b >= '0' .AND. c_E1b <= '2') .OR. c_E1b = ' ') .AND.;
       ((c_E1c >= '0' .AND. c_E1c <= '2') .OR. c_E1c = ' ') .AND.;
       ((c_E1d >= '0' .AND. c_E1d <= '2') .OR. c_E1d = ' ') .AND.;
       ((c_E1e >= '0' .AND. c_E1e <= '2') .OR. c_E1e = ' ') .AND.;
       ((c_E1f >= '0' .AND. c_E1f <= '2') .OR. c_E1f = ' ') .AND.;
       ((c_E1g >= '0' .AND. c_E1g <= '2') .OR. c_E1g = ' ') .AND.;
       ((c_E1h >= '0' .AND. c_E1h <= '2') .OR. c_E1h = ' ') .AND.;
       ((c_E1i >= '0' .AND. c_E1i <= '2') .OR. c_E1i = ' ') .AND.;
       ((c_E1j >= '0' .AND. c_E1j <= '2') .OR. c_E1j = ' ') .AND.;
       ((c_E1k >= '0' .AND. c_E1k <= '2') .OR. c_E1k = ' ') .AND.;
       ((c_E1l >= '0' .AND. c_E1l <= '2') .OR. c_E1l = ' ') .AND.;
       ((c_E1m >= '0' .AND. c_E1m <= '2') .OR. c_E1m = ' ') .AND.;
       ((c_E1n >= '0' .AND. c_E1n <= '2') .OR. c_E1n = ' ') .AND.;
       ((c_E1o >= '0' .AND. c_E1o <= '2') .OR. c_E1o = ' ') .AND.;
       ((c_E1p >= '0' .AND. c_E1p <= '2') .OR. c_E1p = ' ') .AND.;
       ((c_E2  >= '0' .AND. c_E2  <= '2') .OR. c_E2  = ' '))       
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP08

*----------------------------------------------------------------------
Function RAP09
*Process RAP09--Behavior Symptoms

*Scan values for RAP status
IF ((c_E4aA >= '1' .AND. c_E4aA <= '3') .OR.;
    (c_E4bA >= '1' .AND. c_E4bA <= '3') .OR.;
    (c_E4cA >= '1' .AND. c_E4cA <= '3') .OR.;
    (c_E4dA >= '1' .AND. c_E4dA <= '3') .OR.;
    (c_E4eA >= '1' .AND. c_E4eA <= '3') .OR.;
    (c_E5   = '1'))
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF (((c_E4aA >= '0' .AND. c_E4aA <= '3') .OR. c_E4aA = ' ') .AND.;
       ((c_E4bA >= '0' .AND. c_E4bA <= '3') .OR. c_E4bA = ' ') .AND.;
       ((c_E4cA >= '0' .AND. c_E4cA <= '3') .OR. c_E4cA = ' ') .AND.;
       ((c_E4dA >= '0' .AND. c_E4dA <= '3') .OR. c_E4dA = ' ') .AND.;
       ((c_E4eA >= '0' .AND. c_E4eA <= '3') .OR. c_E4eA = ' ') .AND.;
       ((c_E5   >= '0' .AND. c_E5   <= '2') .OR. c_E5   = ' '))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP09

*----------------------------------------------------------------------
Function RAP10
*Process RAP10--Activities

*****************************************************************
*The logic for this RAP is complicated by the fact that the RAP *
*is triggered by any of four different conditions:              *
*                                                               *
*   1.  A value of 2 or 3 on N2, OR                             *
*   2.  A value of 1 or 2 on N5a, OR                            *
*   3.  A value of 1 or 2 on N5b, OR                            *
*   4.  A combination of the value 1 for N1a and 0 for N2.      *
*                                                               *
*The last condition, involving a combination of values on two   *
*different items, is the cause of the complexity in determining *
*if the RAP status is "not triggered" or unknown".  A Missing   * 
*or invalid value on N1a can be associated with either "not     *
*triggered" or unknown".  
*****************************************************************

*Scan values for RAP status
IF ((c_N2  >= '2' .AND. c_N2  <= '3') .OR.;
    (c_N5a >= '1' .AND. c_N5a <= '2') .OR.;
    (c_N5b >= '1' .AND. c_N5b <= '2') .OR.;
    (c_N1a =  '1' .AND.; 
     c_N2  =  '0'))
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--determine if RAP status is "not triggered" or
   *unknown.  The logic is a bit complicated here.
   
   *Check for all values valid on N2, N5a, N5b
   IF (((c_N2  >= '0' .AND. c_N2  <= '3') .OR. c_N2  = ' ') .AND.;
       ((c_N5a >= '0' .AND. c_N5a <= '2') .OR. c_N5a = ' ') .AND.;
       ((c_N5b >= '0' .AND. c_N5b <= '2') .OR. c_N5b = ' '))
          *No missing or invalid data on N2, N5a, N5b 
          *Check for all valid values on N1a
          IF ( c_N1a =  '0' .OR.  c_N1a =  '1')
             *No missing or invalid data on any item--RAP is not 
             *   triggered--return code of '0'
              RETURN '0'
          ELSE
             *Missing or invalid value on N1a but valid values for N2, N5a
             *   and N5b.
             *Check N2 for value of '0'
             IF (c_N2 = '0')
                *N2 = 0 and N1a is missing or invalid--RAP status is 
                *   unknown--return code of '-'
                RETURN '-'
             ELSE
                *N2 does not = 0 but is a valid nonmissing value, RAP is 
                *   not triggered--return code of '0'
                RETURN '0'
             ENDIF
          ENDIF
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values on N2, N5a, or N5b--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP10

*----------------------------------------------------------------------
Function RAP11
*Process RAP11--Falls

*Scan values for RAP status
IF ( c_J4a  =  '1'                      .OR.;
     c_J4b  =  '1'                      .OR.;
    (c_E4aA >= '1' .AND. c_E4aA <= '3') .OR.;
     c_J1f  =  '1'                      .OR.; 
    (c_P4c  >= '1' .AND. c_P4c  <= '2') .OR.;
    (c_O4b  >= '1' .AND. c_O4b  <= '7') .OR.;
    (c_O4c  >= '1' .AND. c_O4c  <= '7'))
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF (( c_J4a  =  '0' .OR.  c_J4a  =  '1'                   ) .AND.;
       ( c_J4b  =  '0' .OR.  c_J4b  =  '1'                   ) .AND.;
       ((c_E4aA >= '0' .AND. c_E4aA <= '3') .OR. c_E4aA = ' ') .AND.;
       ( c_J1f  =  '0' .OR.  c_J1f  =  '1'                   ) .AND.; 
       ( c_P4c  >= '0' .AND. c_P4c  <= '2'                   ) .AND.;
       ( c_O4b  >= '0' .AND. c_O4b  <= '7'                   ) .AND.;
       ( c_O4c  >= '0' .AND. c_O4c  <= '7'                   )) 
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP11

*----------------------------------------------------------------------
Function RAP12
*Process RAP12--Nutritional Status

*Scan values for RAP status
IF ( c_K3a  =  '1'                   .OR.;
     c_K4a  =  '1'                   .OR.;
     c_K4c  =  '1'                   .OR.;
     c_K5a  =  '1'                   .OR.; 
     c_K5c  =  '1'                   .OR.;
     c_K5d  =  '1'                   .OR.;
     c_K5e  =  '1'                   .OR.;
    (c_M2a  >= '2' .AND. c_M2a  <= '4'))
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF ((c_K3a =  '0' .OR.  c_K3a =  '1') .AND.;
       (c_K4a =  '0' .OR.  c_K4a =  '1') .AND.;
       (c_K4c =  '0' .OR.  c_K4c =  '1') .AND.;
       (c_K5a =  '0' .OR.  c_K5a =  '1') .AND.; 
       (c_K5c =  '0' .OR.  c_K5c =  '1') .AND.;
       (c_K5d =  '0' .OR.  c_K5d =  '1') .AND.;
       (c_K5e =  '0' .OR.  c_K5e =  '1') .AND.;
       (c_M2a >= '0' .AND. c_M2a <= '4'))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP12

*----------------------------------------------------------------------
Function RAP13
*Process RAP13--Feeding Tubes

*Scan values for RAP status
IF ( c_K5b = '1')
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF (c_K5b = '0' .OR. c_K5b = '1')
      *RAP is not triggered--return code of '0'
      RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP13

*----------------------------------------------------------------------
Function RAP14
*Process RAP14--Dehyration/Fluid Maintenance

*Scan values for RAP status
IF ( c_J1c  =  '1'                 .OR.;
     c_J1d  =  '1'                 .OR.;
     c_I2j  =  '1'                 .OR.;
     c_I3a  =  ' 276.5 '           .OR.;
     c_I3b  =  ' 276.5 '           .OR.;
     c_I3c  =  ' 276.5 '           .OR.;
     c_I3d  =  ' 276.5 '           .OR.;
     c_I3e  =  ' 276.5 '           .OR.;
     c_J1a  =  '1'                 .OR.;
     c_J1h  =  '1'                 .OR.;
     c_J1j  =  '1'                 .OR.;
     c_K5a  =  '1'                 .OR.;
     c_K5b  =  '1'                 .OR.;
    (c_O4e  >= '1' .AND. c_O4e  <= '7'))
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF ((c_J1c  =  '0' .OR.  c_J1c  =  '1') .AND.;
       (c_J1d  =  '0' .OR.  c_J1d  =  '1') .AND.;
       (c_I2j  =  '0' .OR.  c_I2j  =  '1') .AND.;
       (c_J1a  =  '0' .OR.  c_J1a  =  '1') .AND.; 
       (c_J1h  =  '0' .OR.  c_J1h  =  '1') .AND.;
       (c_J1j  =  '0' .OR.  c_J1j  =  '1') .AND.;
       (c_K5a  =  '0' .OR.  c_K5a  =  '1') .AND.;
       (c_K5b  =  '0' .OR.  c_K5b  =  '1') .AND.;
       (c_O4e  >= '0' .AND. c_O4e  <= '7'))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP14

*----------------------------------------------------------------------
Function RAP15
*Process RAP15--Dental Care

*Scan values for RAP status
IF ( c_L1a  = '1' .OR.;
     c_L1f  = '0' .OR.;
     c_K1c  = '1' .OR.;
     c_L1c  = '1' .OR.;
     c_L1d  = '1' .OR.;
     c_L1e  = '1')
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF ((c_L1a  = '0' .OR. c_L1a  = '1') .AND.;
       (c_L1f  = '0' .OR. c_L1f  = '1') .AND.;
       (c_K1c  = '0' .OR. c_K1c  = '1') .AND.;
       (c_L1c  = '0' .OR. c_L1c  = '1') .AND.; 
       (c_L1d  = '0' .OR. c_L1d  = '1') .AND.;
       (c_L1e  = '0' .OR. c_L1e  = '1'))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP15

*----------------------------------------------------------------------
Function RAP16
*Process RAP16--Pressure Ulcers

*Scan values for RAP status
IF ( (c_M2a  >= '1' .AND. c_M2a  <= '4')                    .OR.;
    ((c_G1aA >= '2' .AND. c_G1aA <= '4') .OR. c_G1aA = '8') .OR.;
      c_G6a  =  '1'                                         .OR.;
     (c_H1a  >= '1' .AND. c_H1a  <= '4')                    .OR.;
      c_I1j  =  '1'                                         .OR.;
      c_M3   =  '1'                                         .OR.;
      c_M4e  =  '1'                                         .OR.;
      c_P4c  =  '2')
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF (( c_M2a  >= '0' .AND. c_M2a  <= '4'                   ) .AND.;
       ((c_G1aA >= '0' .AND. c_G1aA <= '4') .OR. c_G1aA = '8') .AND.;
       ( c_G6a  =  '0' .OR.  c_G6a  =  '1'                   ) .AND.;
       ( c_H1a  >= '0' .AND. c_H1a  <= '4'                   ) .AND.;
       ( c_I1j  =  '0' .OR.  c_I1j  =  '1'                   ) .AND.;
       ( c_M3   =  '0' .OR.  c_M3   =  '1'                   ) .AND.;
       ( c_M4e  =  '0' .OR.  c_M4e  =  '1'                   ) .AND.;
       ( c_P4c  >= '0' .AND. c_P4c  <= '2'                   ))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP16

*----------------------------------------------------------------------
Function RAP17
*Process RAP17--Psychotropic Drug Use

*****************************************************************
*The logic for this RAP is complicated by the fact that the RAP *
*is triggered by the combination of a nonzero value on          *
*O4a, O4b, or O4c with a triggering value from one of the       *
*remaining items.  A missing value on an item may be associated *
*with a "not triggered" or "unknow" RAP status, depending on    *
*values for the other items.                                    *
*****************************************************************

*Scan values for RAP status
IF (((c_O4a  >= '1' .AND. c_O4a  <= '7') .OR.;
     (c_O4b  >= '1' .AND. c_O4b  <= '7') .OR.;
     (c_O4c  >= '1' .AND. c_O4c  <= '7'));
                    .AND.;
    ((c_E1n  >= '1' .AND. c_E1n  <= '2') .OR.;
     (c_G3b  >= '1' .AND. c_G3b  <= '3') .OR.;
      c_I1i  =  '1'                      .OR.;
      c_J1f  =  '1'                      .OR.;
      c_J1m  =  '1'                      .OR.;
      c_J1n  =  '1'                      .OR.;
      c_J4a  =  '1'                      .OR.;
      c_J4b  =  '1'                      .OR.;
      c_J4c  =  '1'                      .OR.;
      c_K1b  =  '1'                      .OR.;
      c_B5a  =  '2'                      .OR.;
      c_B5b  =  '2'                      .OR.;
      c_B5c  =  '2'                      .OR.;
      c_B5d  =  '2'                      .OR.;
      c_B5e  =  '2'                      .OR.;
      c_B5f  =  '2'                      .OR.;
      c_B6   =  '2'                      .OR.;
      c_C7   =  '2'                      .OR.;
      c_E3   =  '2'                      .OR.;
      c_E5   =  '2'                      .OR.;
      c_I1ee =  '1'                      .OR.;
      c_J1i  =  '1'                      .OR.;
      c_H2b  =  '1'                      .OR.;
      c_H2d  =  '1'                      .OR.;
      c_J1k  =  '1'))
         *RAP triggered--return code of '1'
         RETURN '1'
ELSE
   *RAP not triggered--check for all 0 values on psychotropic medications
   IF (c_O4a  = '0' .AND. c_O4b  = '0' .AND. c_O4c  = '0')
      *Values for psychotrophic medications all 0--RAP is not
      *   triggered--return code of '0' 
      RETURN '0'
   ELSE
      *Missing or invalid values present for psychotropic medications.
      *   Check for all valid nontriggering values on remaining items.
      IF (( c_E1n  =  '0' .OR. c_E1n = ' '                     ) .AND.;
          ( c_G3b  =  '0'                                      ) .AND.;
          ( c_I1i  =  '0'                                      ) .AND.;
          ( c_J1f  =  '0'                                      ) .AND.;
          ( c_J1m  =  '0'                                      ) .AND.;
          ( c_J1n  =  '0'                                      ) .AND.;
          ( c_J4a  =  '0'                                      ) .AND.;
          ( c_J4b  =  '0'                                      ) .AND.;
          ( c_J4c  =  '0'                                      ) .AND.;
          ( c_K1b  =  '0'                                      ) .AND.;
          ((c_B5a  >= '0' .AND. c_B5a  <= '1') .OR. c_B5a = ' ') .AND.;
          ((c_B5b  >= '0' .AND. c_B5b  <= '1') .OR. c_B5b = ' ') .AND.;
          ((c_B5c  >= '0' .AND. c_B5c  <= '1') .OR. c_B5c = ' ') .AND.;
          ((c_B5d  >= '0' .AND. c_B5d  <= '1') .OR. c_B5d = ' ') .AND.;
          ((c_B5e  >= '0' .AND. c_B5e  <= '1') .OR. c_B5e = ' ') .AND.;
          ((c_B5f  >= '0' .AND. c_B5f  <= '1') .OR. c_B5f = ' ') .AND.;
          ((c_B6   >= '0' .AND. c_B6   <= '1') .OR. c_B6  = ' ') .AND.;
          ((c_C7   >= '0' .AND. c_C7   <= '1') .OR. c_C7  = ' ') .AND.;
          ((c_E3   >= '0' .AND. c_E3   <= '1') .OR. c_E3  = ' ') .AND.;
          ((c_E5   >= '0' .AND. c_E5   <= '1') .OR. c_E5  = ' ') .AND.;
          ( c_I1ee =  '0'                                      ) .AND.;
          ( c_J1i  =  '0'                                      ) .AND.;
          ( c_H2b  =  '0'                                      ) .AND.;
          ( c_H2d  =  '0'                                      ) .AND.;
          ( c_J1k  =  '0'                                      ))
             *RAP is not triggered--return code of '0'
             RETURN '0'
      ELSE
         *RAP status unknown because of missing or invalid 
         *   values--return code of '-'
         RETURN '-'
      ENDIF
   ENDIF
ENDIF

RETURN nil
*End of Function RAP17

*----------------------------------------------------------------------
Function RAP18
*Process RAP18--Physical Restraints

*Scan values for RAP status
IF ((c_P4c  >= '1' .AND. c_P4c  <= '2') .OR.;
    (c_P4d  >= '1' .AND. c_P4d  <= '2') .OR.;
    (c_P4e  >= '1' .AND. c_P4e  <= '2'))
       *RAP triggered--return code of '1'
       RETURN '1'
ELSE
   *RAP not triggered--check for all values valid
   IF ((c_P4c  >= '0' .AND. c_P4c  <= '2') .AND.;
       (c_P4d  >= '0' .AND. c_P4d  <= '2') .AND.;
       (c_P4e  >= '0' .AND. c_P4e  <= '2'))
           *RAP is not triggered--return code of '0'
           RETURN '0'
   ELSE
      *RAP status unknown because of missing or invalid 
      *   values--return code of '-'
      RETURN '-'
   ENDIF
ENDIF

RETURN nil
*End of Function RAP18

*----------------------------------------------------------------------


*                      END OF CODE
